/***************************************************************************                        
 *   Copyright (C) 2008 by Jaroslav Reznik <jreznik@redhat.com>            *                        
 *                                                                         *                        
 *   This program is free software; you can redistribute it and/or modify  *                        
 *   it under the terms of the GNU General Public License as published by  *                        
 *   the Free Software Foundation; either version 2 of the License, or     *                        
 *   (at your option) any later version.                                   *                        
 *                                                                         *                        
 *   This program is distributed in the hope that it will be useful,       *                        
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *                        
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *                        
 *   GNU General Public License for more details.                          *                        
 *                                                                         *                        
 *   You should have received a copy of the GNU General Public License     *                        
 *   along with this program; if not, write to the                         *                        
 *   Free Software Foundation, Inc.,                                       *                        
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *                        
 ***************************************************************************/ 

#include "mediaplayer.h"

#include <QtGui/QHBoxLayout>
#include <QtGui/QVBoxLayout>
#include <QtGui/QLabel>
#include <QActionGroup>
#include <QBuffer>
#include <QDebug>


#include "kaction.h"
#include "ktoolbar.h"
#include "kiconloader.h"
#include "klocale.h"

#include <Phonon/BackendCapabilities>
#include <Phonon/ObjectDescription>
#include <Phonon/VideoWidget>
#include <Phonon/MediaObject>
#include <Phonon/MediaSource>
#include <Phonon/AudioOutput>
#include <Phonon/SeekSlider>
#include <Phonon/VolumeSlider>

MediaPlayer::MediaPlayer(QWidget * parent)
{
	m_mainLayout = new QVBoxLayout;

	connect(this, SIGNAL(rejected ()), this, SLOT(close()));

	m_media = new Phonon::MediaObject;
	connect(m_media, SIGNAL(stateChanged(Phonon::State, Phonon::State)), this, SLOT(stateChanged(Phonon::State)));

	// create video widget
	m_video = new Phonon::VideoWidget;
	m_mainLayout->addWidget(m_video, 1);

	// create audio device
	m_audio = new Phonon::AudioOutput(Phonon::VideoCategory);

	// create seek slider
	m_seekSlider = new Phonon::SeekSlider;
	m_seekSlider->setMediaObject(m_media);
	m_mainLayout->addWidget(m_seekSlider);

	// and toolbar
	m_playerToolBar = new KToolBar(this);
	m_playerToolBar->setIconDimensions(32);
	m_playerToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);

	QActionGroup *groupMode = new QActionGroup(this);

	actionPlaybackStart = new KAction(KIcon("media-playback-start"), i18n("Play"), groupMode);
	m_playerToolBar->addAction(actionPlaybackStart);
	connect(actionPlaybackStart, SIGNAL(triggered()), this, SLOT(playbackStart()));
 
	actionPlaybackStop = new KAction(KIcon("media-playback-stop"), i18n("Stop"), groupMode);
	m_playerToolBar->addAction(actionPlaybackStop);
	connect(actionPlaybackStop, SIGNAL(triggered()), this, SLOT(playbackStop()));
	actionPlaybackStop->setEnabled(false);

	actionViewFullscreen = new KAction(KIcon("view-fullscreen"), i18n("View fullscreen"), groupMode);
	m_playerToolBar->addAction(actionViewFullscreen);
	connect(actionViewFullscreen, SIGNAL(triggered()), this, SLOT(viewFullscreen()));

	m_volumeSlider = new Phonon::VolumeSlider;
	m_volumeSlider->setAudioOutput(m_audio);
	m_playerToolBar->addWidget(m_volumeSlider);
	
	m_mainLayout->addWidget(m_playerToolBar);

	// now lets create paths
	Phonon::createPath(m_media, m_video);
	Phonon::createPath(m_media, m_audio);

	resize(300, 350);

	setLayout(m_mainLayout);
}

void MediaPlayer::setCurrentSource(const Phonon::MediaSource &source)
{
	m_media->setCurrentSource(source);

	m_video->show();
	resize(300, 350);
}

void MediaPlayer::createButtons()
{
}

void MediaPlayer::playbackStart()
{
	if (!m_media)
		return;

	switch (m_media->state())
	{
	case Phonon::StoppedState:
	case Phonon::PausedState:
		m_media->play();
		break;

	case Phonon::PlayingState:
		m_media->pause();
		break;

	default:
		break;
	}
}

void MediaPlayer::playbackStop()
{
	if (!m_media)
		return;

	m_media->stop();
	
}

void MediaPlayer::viewFullscreen()
{
	if (!m_video)
		return;

	m_video->setFullScreen(true);
}

void MediaPlayer::stateChanged(Phonon::State state)
{
	switch (state)
	{
	case Phonon::StoppedState:
		actionPlaybackStop->setEnabled(false);
	case Phonon::PausedState:
		actionPlaybackStart->setIcon(KIcon("media-playback-start"));
		break;

	case Phonon::PlayingState:
		actionPlaybackStart->setIcon(KIcon("media-playback-pause"));
		actionPlaybackStop->setEnabled(true);
		break;

	default:
		break;
	}
}

void MediaPlayer::close()
{
	m_media->stop();
}

#include "mediaplayer.moc"
